==> jc-1.4.0.tar.gz: gnu/java/util/prefs/FileBasedFactory.h <==
// public class gnu.java.util.prefs.FileBasedFactory

// class file dependencies
// @dep_class 43799c8bf604478c gnu_java_util_prefs_FileBasedFactory
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_prefs_FileBasedFactory_H_
#define _JC_gnu_java_util_prefs_FileBasedFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_refs	_jc_gnu_java_util_prefs_FileBasedFactory$sub_refs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs	_jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$refs	_jc_gnu_java_util_prefs_FileBasedFactory$refs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$nonrefs	_jc_gnu_java_util_prefs_FileBasedFactory$nonrefs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$object	_jc_gnu_java_util_prefs_FileBasedFactory$object;

typedef const struct _jc_gnu_java_util_prefs_FileBasedFactory$vmethods	_jc_gnu_java_util_prefs_FileBasedFactory$vmethods;
typedef const struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable	_jc_gnu_java_util_prefs_FileBasedFactory$vtable;
typedef const struct _jc_gnu_java_util_prefs_FileBasedFactory$vtype	_jc_gnu_java_util_prefs_FileBasedFactory$vtype;

// Constructors
extern void _jc_gnu_java_util_prefs_FileBasedFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *);

// Virtual methods
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *);
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0;
extern _jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d;

// Virtual methods structure
struct _jc_gnu_java_util_prefs_FileBasedFactory$vmethods {
	struct _jc_java_util_prefs_Preferences$object	*(*systemRoot$bf0a6df2e99738a0)(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *);
	struct _jc_java_util_prefs_Preferences$object	*(*userRoot$b327c33849f7289d)(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *);
};

// Vtable
struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_prefs_FileBasedFactory$vmethods	gnu_java_util_prefs_FileBasedFactory;
};

// Vtype
struct _jc_gnu_java_util_prefs_FileBasedFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_util_prefs_FileBasedFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_util_prefs_FileBasedFactory$refs {
    _jc_gnu_java_util_prefs_FileBasedFactory$sub_refs	gnu_java_util_prefs_FileBasedFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_prefs_FileBasedFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs	gnu_java_util_prefs_FileBasedFactory;
};

// Object instance structure
struct _jc_gnu_java_util_prefs_FileBasedFactory$object {
	_jc_gnu_java_util_prefs_FileBasedFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_prefs_FileBasedFactory$vtype	*vtype;
	_jc_gnu_java_util_prefs_FileBasedFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_prefs_FileBasedFactory$vtype _jc_gnu_java_util_prefs_FileBasedFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_prefs_FileBasedFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_prefs_FileBasedFactory$class_object;

#endif	/* _JC_gnu_java_util_prefs_FileBasedFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/java/util/prefs/FileBasedFactory.h <==
// public class gnu.java.util.prefs.FileBasedFactory

// class file dependencies
// @dep_class 43799c8bf604478c gnu_java_util_prefs_FileBasedFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_prefs_FileBasedFactory_H_
#define _JC_gnu_java_util_prefs_FileBasedFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_refs	_jc_gnu_java_util_prefs_FileBasedFactory$sub_refs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs	_jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$refs	_jc_gnu_java_util_prefs_FileBasedFactory$refs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$nonrefs	_jc_gnu_java_util_prefs_FileBasedFactory$nonrefs;
typedef struct _jc_gnu_java_util_prefs_FileBasedFactory$object	_jc_gnu_java_util_prefs_FileBasedFactory$object;

typedef const struct _jc_gnu_java_util_prefs_FileBasedFactory$vmethods	_jc_gnu_java_util_prefs_FileBasedFactory$vmethods;
typedef const struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable	_jc_gnu_java_util_prefs_FileBasedFactory$vtable;
typedef const struct _jc_gnu_java_util_prefs_FileBasedFactory$vtype	_jc_gnu_java_util_prefs_FileBasedFactory$vtype;

// Constructors
extern void _jc_gnu_java_util_prefs_FileBasedFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0;
extern _jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d;

// Virtual methods structure
struct _jc_gnu_java_util_prefs_FileBasedFactory$vmethods {
	struct _jc_java_util_prefs_Preferences$object	*(*systemRoot$bf0a6df2e99738a0)(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_prefs_Preferences$object	*(*userRoot$b327c33849f7289d)(_jc_env *, struct _jc_gnu_java_util_prefs_FileBasedFactory$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_prefs_FileBasedFactory$vmethods	gnu_java_util_prefs_FileBasedFactory;
};

// Vtype
struct _jc_gnu_java_util_prefs_FileBasedFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_util_prefs_FileBasedFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_util_prefs_FileBasedFactory$refs {
    _jc_gnu_java_util_prefs_FileBasedFactory$sub_refs	gnu_java_util_prefs_FileBasedFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_prefs_FileBasedFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_prefs_FileBasedFactory$sub_nonrefs	gnu_java_util_prefs_FileBasedFactory;
};

// Object instance structure
struct _jc_gnu_java_util_prefs_FileBasedFactory$object {
	_jc_gnu_java_util_prefs_FileBasedFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_prefs_FileBasedFactory$vtype	*vtype;
	_jc_gnu_java_util_prefs_FileBasedFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_prefs_FileBasedFactory$vtype _jc_gnu_java_util_prefs_FileBasedFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_prefs_FileBasedFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_prefs_FileBasedFactory$class_object;

#endif	/* _JC_gnu_java_util_prefs_FileBasedFactory_H_ */
